(generate-secret-key)Generate a secret key for use in TOTP/HOTP.
Generate a secret key for use in TOTP/HOTP.
(get-hotp-token secret counter)Gets the HOTP token for the secret and counter provided
Gets the HOTP token for the secret and counter provided
(get-totp-token secret)(get-totp-token secret
{:keys [date time-step time-step-offset hmac-sha-type] :as all})Gets the TOTP token for the secret and parameters provided
Gets the TOTP token for the secret and parameters provided
(is-valid-hotp-token? token secret counter)Checks if the presented hotp token is valid against a secret and counter
Checks if the presented hotp token is valid against a secret and counter
(is-valid-totp-token? token secret)(is-valid-totp-token? token secret options)Checks if the presented totp token is valid against a secret and options
Checks if the presented totp token is valid against a secret and options
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |