(get-token secret)(get-token
secret
{:keys [date time-step time-step-offset hmac-sha-type]
:or
{date (Date.) time-step 30 time-step-offset 0 hmac-sha-type :hmac-sha-1}})Return a TOTP token (Time-Based One-Time Password Algorithm) based on a secret and time, as specified in https://tools.ietf.org/html/rfc4226
Return a TOTP token (Time-Based One-Time Password Algorithm) based on a secret and time, as specified in https://tools.ietf.org/html/rfc4226
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |