(get-token secret counter)(get-token secret counter hmac-sha-type)Return a HOTP token (HMAC-Based One-Time Password Algorithm) based on a secret and a counter, as specified in https://tools.ietf.org/html/rfc4226
Return a HOTP token (HMAC-Based One-Time Password Algorithm) based on a secret and a counter, as specified in https://tools.ietf.org/html/rfc4226
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |